@@ -201,7 +201,7 @@ __END__
 
 =head1 AUTHOR
 
-Shlomi Fish, E<lt>shlomif@iglu.org.ilE<gt>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 COPYRIGHT AND LICENSE
 
